iddistBox: Compute Interval Distances for the Hyperbox Model

.idistBoxR Documentation

Compute Interval Distances for the Hyperbox Model

Description

Internal function for computing interval-valued distances between objects represented by hyperboxes.

Usage

.idistBox(X, R)

Arguments

X

A numeric matrix containing the coordinates of the centers of the hyperboxes. Rows correspond to objects and columns to dimensions.

R

A numeric matrix containing the half-ranges (radii) of the hyperboxes. It must have the same dimensions as X.

Details

The function computes interval-valued dissimilarities between pairs of hyperboxes defined by their centers X and their half-ranges R.

It is an internal utility used by the interval-valued multidimensional scaling procedures in the mdsOpt package and is not normally called directly by users.

Value

A three-dimensional array representing an interval-valued dissimilarity matrix. The first layer contains the lower bounds of the pairwise distances and the second layer contains the upper bounds.

See Also

optSmacofSymInterval


mdsOpt documentation built on Oct. 2, 2026, 5:09 p.m.

Related to iddistBox in mdsOpt...