ispb: Calculation of I-stress per box indices for multidimensional...

View source: R/ispb.r

ispbR Documentation

Calculation of I-stress per box indices for multidimensional scaling procedure for interval-valued data

Description

Calculation of I-stress per box indices for multidimensional scaling procedure for interval-valued data

Usage

ispb(EIDM,idiss)

Arguments

EIDM

the interval-valued dissimilarity matrix IDM (an object of class "array": IDM[1,,]: the lower dissmilarity matrix; IDM[2,,]: the upper dissmilarity matrix) in reduced space

idiss

the primary interval-valued dissimilarity matrix

Value

The vector of i-stress per box percentage values

Author(s)

Marek Walesiak marek.walesiak@ue.wroc.pl

Department of Econometrics and Computer Science, Wroclaw University of Economics and Business, Poland

Andrzej Dudek andrzej.dudek@ue.wroc.pl

Department of Financial Investments and Risk Management, Wroclaw University of Economics and Business, Poland

References

Borg, I., Groenen, P.J.F. (2005), Modern Multidimensional Scaling. Theory and Applications, 2nd Edition, Springer Science+Business Media, New York. ISBN: 978-0387-25150-9. Available at: https://link.springer.com/book/10.1007/0-387-28981-X.

Borg, I., Groenen, P.J.F., Mair, P. (2013), Applied Multidimensional Scaling, Springer, Heidelberg, New York, Dordrecht, London. Available at: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/978-3-642-31848-1")}.

Groenen, P.J.F. Winsberg, S., Rodriguez, O., Diday, E. (2006), I-Scal: Multidimensional scaling of interval dissimilarities, Computational Statistics & Data Analysis, 51(1), 360–378. Available at: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.csda.2006.04.003")}.

Walesiak, M. (2014), Przegląd formuł normalizacji wartości zmiennych oraz ich własności w statystycznej analizie wielowymiarowej [Data Normalization in Multivariate Data Analysis. An Overview and Properties], Przegląd Statystyczny, tom 61, z. 4, 363-372

Walesiak, M., Dudek, A. (2017), Selecting the Optimal Multidimensional Scaling Procedure for Metric Data with R Environment, STATISTICS IN TRANSITION new series, September, Vol. 18, No. 3, pp. 521-540. Available at: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.59170/stattrans-2017-027")}.

Walesiak, M., Dehnel, G. (2020), The Measurement of Social Cohesion at Province Level in Poland Using Metric and Interval-Valued Data, Sustainability, 12(18), 7664, 1-19. Available at: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3390/su12187664")}.

Walesiak, M., Dehnel, G., Dudek, A. (2025), Visualisation of linear ordering results using multidimensional scaling – problems and an overview of studies, Argumenta Oeconomica, No 1 (54), 187-203. Available at: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.15611/aoe.2025.1.12")}.

Walesiak, M., Dehnel, G. (2026), Assessment of the implementation of SDG 4 goal by EU countries in the light of the 2030 Agenda using a hybrid approach in linear ordering, PLoS ONE 21(6): e0333545. Available at: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1371/journal.pone.0333545")}.

See Also

data.Normalization, interval_normalization

Examples


library(mdsOpt)
library(clusterSim)
data(data_symbolic_interval_polish_voivodships)
x1<-data_symbolic_interval_polish_voivodships[,,1]
y1<-data_symbolic_interval_polish_voivodships[,,2]
norm_type="n2" 
normalized<-interval_normalization(x=x1,y=y1,dataType="separate_tables",type=norm_type)
x<-normalized$simple[,,1]
y<-normalized$simple[,,2]
my.idiss<-.idistBox(X=(x+y)/2,R=(y-x)/2)
#Apply the hyperbox model via the MM algorithm
cmat<-(my.idiss[2, , ] + my.idiss[1, , ])/2
iniX<-cmdscale(as.dist(cmat), k = 2)
n=dim(my.idiss)[2]
iniR<-matrix(rep(1,n * 2), nrow = n, ncol = 2)
res.mm_box<-.IMDS(IDM=my.idiss, p=2,model="box",opt.method="MM", ini=list(iniX,iniR))
.plot.imds(res.mm_box)
title(main="box_MM")
#windows()
spb<-ispb(res.mm_box$EIDM,my.idiss)
w<-sort(spb,decreasing=TRUE)
print(spb)
names(w)<-order(spb,decreasing = TRUE)
plot(w, xlab="Object", ylab="spb in percents")
text(w,pos=1,names(w))

mdsOpt documentation built on Oct. 2, 2026, 5:09 p.m.

Related to ispb in mdsOpt...