plot.imds: Plot an Interval Multidimensional Scaling Configuration

.plot.imdsR Documentation

Plot an Interval Multidimensional Scaling Configuration

Description

Internal plotting function for visualizing the results of interval-valued multidimensional scaling.

Usage

.plot.imds(x,
  xylim = "auto",
  clab = 1:nrow(X),
  lab.cex = 1,
  lab.col = "black",
  ...
)

Arguments

x

An object containing the result of interval multidimensional scaling, typically produced by an internal IMDS optimization procedure. The object should contain the coordinates and interval representation required for plotting the fitted configuration.

xylim

Controls the limits of the plotting area. If set to "auto", the plotting limits are determined automatically from the data. Alternatively, plotting limits can be supplied explicitly.

clab

Labels used for the plotted objects. By default, consecutive integer labels from 1 to nrow(X) are used.

lab.cex

Numeric value controlling the size of the object labels. The default is 1.

lab.col

Color used for the object labels. The default is "black".

...

Additional graphical parameters passed to the underlying plotting functions.

Details

The function provides a graphical representation of an interval-valued multidimensional scaling configuration.

Objects are displayed together with their corresponding labels. The plot limits can be determined automatically or supplied by the user, while label size and color can be controlled using lab.cex and lab.col, respectively.

This is an internal plotting utility used by functions in the mdsOpt package and is not normally intended to be called directly by users.

Value

The function is called primarily for its graphical side effect.

It produces a plot of the interval multidimensional scaling configuration and does not return a meaningful value.

See Also

.IMDS


mdsOpt documentation built on Oct. 2, 2026, 5:09 p.m.

Related to plot.imds in mdsOpt...