| .IMDS | R Documentation |
Internal function for multidimensional scaling of interval-valued dissimilarities using either the hypersphere or hyperbox model. Optimization can be performed using the majorization-minimization algorithm or the BFGS quasi-Newton method.
.IMDS(
IDM,
p = 2,
eps = 1e-5,
maxit = 1000,
model = c("sphere", "box"),
opt.method = c("MM", "BFGS"),
ini = "auto",
report = 100,
grad.num = FALSE,
rel = 0,
dil = 1
)
IDM |
Interval-valued dissimilarity matrix represented as a
three-dimensional array. |
p |
Number of dimensions of the multidimensional scaling configuration. |
eps |
Convergence criterion used by the majorization-minimization algorithm. |
maxit |
Maximum number of optimization iterations. |
model |
Character string specifying the symbolic representation.
|
opt.method |
Optimization method. |
ini |
Initial configuration. If |
report |
Frequency with which optimization progress is reported. |
grad.num |
Logical value indicating whether a numerical gradient should be
used for BFGS optimization. If |
rel |
Control parameter for the relaxed update used by the majorization-minimization procedure. A nonzero value enables the relaxed update. This argument is not used for BFGS optimization. |
dil |
Control parameter for optimal dilation of the configuration in the majorization-minimization procedure. A nonzero value enables dilation. This argument is not used for BFGS optimization. |
The function performs multidimensional scaling for interval-valued dissimilarities.
Two representations are available. In the hypersphere model each object is represented by a center and a radius. In the hyperbox model each object is represented by a center and dimension-specific half-ranges.
The stress criterion can be minimized either by the majorization-minimization method or by the BFGS optimization method.
This is an internal function used by higher-level procedures in the mdsOpt package and is not normally intended to be called directly by users.
An object containing the fitted interval multidimensional scaling configuration. Depending on the selected model, components can include:
XMatrix of coordinates of the object centers with p
columns.
rRadius vector for the hypersphere model.
RRadius or half-range matrix for the hyperbox model.
strValue of the stress criterion for the fitted configuration.
IDMOriginal interval-valued dissimilarity matrix.
EIDMInterval-valued dissimilarities implied by the fitted configuration.
Nash, J. C. (1990). Compact Numerical Methods for Computers: Linear Algebra and Function Minimisation. Adam Hilger.
Borg, I., Groenen, P. J. F., and Mair, P. (2013). Applied Multidimensional Scaling. Springer.
optSmacofSymInterval
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.