| .plot.imds | R Documentation |
Internal plotting function for visualizing the results of interval-valued multidimensional scaling.
.plot.imds(x,
xylim = "auto",
clab = 1:nrow(X),
lab.cex = 1,
lab.col = "black",
...
)
x |
An object containing the result of interval multidimensional scaling, typically produced by an internal IMDS optimization procedure. The object should contain the coordinates and interval representation required for plotting the fitted configuration. |
xylim |
Controls the limits of the plotting area. If set to |
clab |
Labels used for the plotted objects. By default, consecutive integer
labels from |
lab.cex |
Numeric value controlling the size of the object labels.
The default is |
lab.col |
Color used for the object labels. The default is |
... |
Additional graphical parameters passed to the underlying plotting functions. |
The function provides a graphical representation of an interval-valued multidimensional scaling configuration.
Objects are displayed together with their corresponding labels. The plot
limits can be determined automatically or supplied by the user, while
label size and color can be controlled using lab.cex and
lab.col, respectively.
This is an internal plotting utility used by functions in the mdsOpt package and is not normally intended to be called directly by users.
The function is called primarily for its graphical side effect.
It produces a plot of the interval multidimensional scaling configuration and does not return a meaningful value.
.IMDS
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.